/*

Copyright (C) 2000, 2001, 2002 Christian Kreibich <christian@whoop.org>.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies of the Software and its documentation and acknowledgment shall be
given in the documentation and software packages that this Software was
used.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*/
#ifndef __nd_protocol_registry_h
#define __nd_protocol_registry_h

#include <netdude/nd.h>
#include <netdude/nd_protocol.h>

typedef void (*ND_ProtocolFunc)(ND_Protocol *proto, void *user_data);

/* Initializes the registry -- sets up hashes etc. */
void           nd_proto_registry_init(void);

/* Protocol registration routine. For normal protocol plugins, this
   gets automatically called when the plugin is loaded and initialized,
   so you don't have to do this manually. */
gboolean       nd_proto_registry_register(ND_Protocol *proto);
void           nd_proto_registry_unregister(ND_Protocol *proto);

/* Looks up a protocol plugin for a given protocol layer and magic.
   If the protocol isn't found, the raw data display plugin is
   returned, which you can discern by a protocol ID value of 1. */
ND_Protocol   *nd_proto_registry_find(ND_ProtocolLayer layer, guint64 magic);

/* Returns the number of protocols in the registry. */
guint          nd_proto_registry_size(void);

/* Applies a callback function to each of the registered protocols. */
void           nd_proto_registry_foreach_proto(ND_ProtocolFunc callback,
					       void *user_data);

#endif
